@@ -169,8 +169,9 @@ class Modela:
                 port = s.getsockname()[1]
 
             self.pf_process = subprocess.Popen("kubectl port-forward svc/modela-api-gateway %d:8080 -n modela-system" % port,
-                                               shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
+                                               shell=True, stderr=subprocess.STDOUT)
 
+            time.sleep(1/4)
             secure, host = False, "localhost"
 
         if secure:
