@@ -53,44 +53,82 @@ class TaskType(Enum):
     AutoDetectTask = "auto"
 
 
-class SubtaskType(Enum):
-    TextClassification = "text-classification"
-    TextMultiClassification = "text-multi-classification"
-    TextRegression = "text-regression"
-    TextMultiLabelClassification = "text-multi-label-classification"
-    TextConversation = "text-conversation"
-    TextLangGeneration = "text-lang-generation"
-    TextLangModel = "text-lang-model"
-    TextMultiModalClassification = "text-multi-modal"
-    TextNER = "text-ner"
-    TextQA = "text-qa"
-    TextSummarization = "text-summarization"
-    TextSentencePairClassification = "text-sentence-pair"
-    TextRepresentationGeneration = "text-representation-generation"
-    TextSentimentAnalysis = "text-sentiment-analysis"
-    TextCodeGeneration = "text-code-generation"
-    TextTranslation = "text-translation"
-    TextLangDetection = "text-lang-detection"
-    TextGrammarCorrection = "text-grammar-correction"
-    TextParaphrasing = "text-paraphrasing"
-    TextIntentClassification = "text-intent-classification"
-    TextSemanticSimilarity = "text-semantic-similarity"
-    TextKeywordExtraction = "text-keyword-extraction"
-    TextPOS = "text-pos"
-    TextTokenization = "text-tokenization"
-    TextLemmalization = "text-lemma"
-
-    ImageClassification = "image-classification"
-    ImageMultiLabelClassification = "image-multi-label-classification"
-    ImageObjectDetection = "image-object-detection"
-    ImageSegmentation = "image-segmentation"
-
-    VideoActionRecognition = "video-action-recognition"
-    VideoClassification = "video-classification"
-    VideoObjectTracking = "video-object-tracking"
-
-    NoneSubtask = "none"
-
+class Metric(Enum):
+    Accuracy = "accuracy"
+    AveragePrecision = "average-precision"
+    BalancedAccuracy = "balanced-accuracy"
+    F1Binary = "f1"
+    F1Micro = "f1-micro"
+    F1Macro = "f1-macro"
+    F1Weighted = "f1-weighted"
+    F1Samples = "f1-samples"
+    PrecisionBinary = "precision"
+    PrecisionMicro = "precision-micro"
+    PrecisionMacro = "precision-macro"
+    PrecisionWeighted = "precision-weighted"
+    PrecisionSamples = "precision-samples"
+    RecallBinary = "recall"
+    RecallMacro = "recall-macro"
+    RecallMicro = "recall-micro"
+    RecallWeighted = "recall-weighted"
+    RecallSamples = "recall-samples"
+    LogLoss = "log-loss"
+    RocAuc = "auc"
+    RocAucMicro = "auc-micro"
+    RocAucMacro = "auc-macro"
+    RocAucWeighted = "auc-weighted"
+    PRRocAuc = "pr-auc"
+    PRRocAucMicro = "pr-auc-micro"
+    PRRocAucMacro = "pr-auc-macro"
+    PRRocAucWeighted = "pr-auc-weighted"
+    ZeroOne = "zero-one"
+    HammingLoss = "hamming-loss"
+    HingeLoss = "hinge-loss"
+    JacquardScore = "jacquard-loss"
+    MatthewsCorrCoef = "mcc"
+    Fp = "fp"
+    Fn = "fn"
+    Tn = "tn"
+    Tp = "tp"
+    Tpr = "tpr"
+    Fpr = "fpr"
+    Tnr = "tnr"
+    MCC = "matthews-corr-coef"
+    ExplainedVariance = "explained-variance"
+    MaxError = "max-error"
+    MAE = "mae"
+    MSE = "mse"
+    MSLE = "msle"
+    RMSE = "rmse"
+    RMSLE = "rmsle"
+    MedianAbsoluteError = "median-absolute-error"
+    R2 = "r2"
+    AdjR2 = "adj-r2"
+    MeanPoissonDeviance = "mean_poisson_deviance"
+    MeanGammaDeviance = "mean-gamma-deviance"
+    MeanTweedieDeviance = "mean-tweedie-deviance"
+    MAPE = "mape"
+    MAZE = "maze"
+    MDAPE = "mdape"
+    SMAPE = "smape"
+    AdjustedMutualInfoScore = "adjusted-mutual-info-score"
+    AdjustedRandScore = "adjusted-rand-score"
+    CompletenessScore = "completeness-score"
+    FowlkesMallowsScore = "fowlkes-mallows-score"
+    HomogeneityScore = "homogeneity-score"
+    MutualInfoScore = "mutual-info-score"
+    NormalizedMutualInfoScore = "normalized-mutual-info-score"
+    VMeasureScore = "v-measure-score"
+    P50Latency = "p50-latency"
+    P95Latency = "p95-latency"
+    P99Latency = "p99-latency"
+    Cpu = "cpu"
+    Gpu = "gpu"
+    Mem = "mem"
+    GpuMem = "gpu-mem"
+    ReqSec = "req-per-sec"
+    UncrainPredictionPercent = "uncertain-prediction-percent"
+    Null = "none"
 
 
 class Imputation(Enum):
@@ -277,7 +315,6 @@ class DataSplitMethod(Enum):
     SplitColumn = "split-column"
     Time = "time"
     Auto = "auto"
-    TestDataset = "test-dataset"
 
 
 class Operation(Enum):
@@ -478,7 +515,7 @@ class StudyPhase(Enum):
     Paused = "Paused"
 
 
-StudyPhaseToProgress = {
+_StudyPhaseToProgress = {
     StudyPhase.ModelPending: "Pending",
     StudyPhase.Splitting: "Splitting Dataset",
     StudyPhase.Splitted: "Split Complete",
@@ -596,13 +633,13 @@ class ModelAutobuilderPhase(Enum):
     Failed = "Failed"
 
 
-class ModelTestName(Enum):
+class ModelValidationType(Enum):
     ModelTest = "model-test"
     PredictionCountDrift = "prediction-count-drift"
     PredictionLatencyDrift = "prediction-latency-drift"
     PredictionLatencySkew = "prediction-latency-skew"
-    ModelPerfSkew = "model-pref-skew"
-    ModelPerfDrift = "model-pref-drift"
+    ModelPrefSkew = "model-pref-skew"
+    ModelPrefDrift = "model-pref-drift"
     CategoricalColumnSkew = "cat-column-skew"
     CategoricalColumnDrift = "cat-column-drift"
     NumericalColumnSkew = "numerical-column-skew"
@@ -620,15 +657,3 @@ class Aggregate(Enum):
     Median = "median"
     Stddev = "stddev"
     Var = "var"
-
-
-class ModelServingFormat(Enum):
-    Protobuf = "protobuf"
-    Pickle = "pickle"
-    CloudPickle = "cloudpickle"
-    MLLeap = "mlleap"
-    MLModel = "mlmodel"
-    H5 = "h5"
-    Onyx = "onyx"
-    Pmml = "pmml"
-    TorchScript = "pt"
