@@ -12,11 +12,13 @@ import pprint
 class Test_Modela_model(unittest.TestCase):
     """Tests for `modela.training.Model`"""
 
-    def setUp(self):
-        self.modela = Modela("localhost", 3000, username="admin", password="admin")
+    @classmethod
+    def setUpClass(cls):
+        cls.modela = Modela(port_forward=True)
 
-    def tearDown(self):
-        self.modela.close()
+    @classmethod
+    def tearDownClass(cls):
+        cls.modela.close()
 
     def test_upload(self):
         with open('datasets/100MB.bin', 'r') as f:
